package com.ruoyi.system.service_shate.impl;

import com.ruoyi.system.domain_shate.DateUpload;
import com.ruoyi.system.mapper_shate.DateUploadMapper;
import com.ruoyi.system.service_shate.IDateUploadService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.List;

/**
 * @Author: JinSheng Song
 * @Date: 2022/7/11 15:44
 */
@Service
public class DateUploadServiceImpl implements IDateUploadService {

    @Resource
    private DateUploadMapper mapper;

    @Override
    public List<DateUpload> selectUpload(String zone,String type,String type1,String type2,String year, String dateWithSway,String name,String dateTime) {
        return mapper.selectUpload(zone,type,type1,type2,year,dateWithSway,name,dateTime);
    }

    @Override
    public DateUpload selectShpfire(String zone, String year, String datetime,String type) {
        return mapper.selectShpfile(zone,type,datetime,year);
    }

    @Override
    public Integer DelUpload(Integer id) {
        return mapper.DelUpload(id);
    }

    @Override
    public Integer IntoUpload(DateUpload upload) {
        return mapper.IntoUpload(upload);
    }

    @Override
    public DateUpload selectShp(String zone, String type, String dateTime) {
        return mapper.selectShp(zone,type,dateTime);
    }

    @Override
    public Integer DelShp(Integer id) {
        return mapper.DelShp(id);
    }

    @Override
    public Integer IntoShp(DateUpload upload) {
        return mapper.IntoShp(upload);
    }

    @Override
    public DateUpload selectDel(Integer id) {
        return mapper.selectDel(id);
    }

    @Override
    public Integer altitude(String zone, String imageDate) {
        return mapper.altitude(zone,imageDate);
    }

    @Override
    public Integer aspect(String zone, String imageDate) {
        return mapper.aspect(zone,imageDate);
    }

    @Override
    public Integer landuse(String zone, String imageDate) {
        return mapper.landuse(zone,imageDate);
    }

    @Override
    public Integer suitability(String zone, String imageDate) {
        return mapper.suitability(zone,imageDate);
    }

    @Override
    public Integer road(String zone, String imageDate) {
        return mapper.road(zone,imageDate);
    }

    @Override
    public Integer seedSuccess(String zone, String imageDate) {
        return mapper.seedSuccess(zone,imageDate);
    }

    @Override
    public Integer vegetationDistribution(String zone, String imageDate) {
        return mapper.vegetationDistribution(zone,imageDate);
    }

    @Override
    public Integer slope(String zone, String imageDate) {
        return mapper.slope(zone,imageDate);
    }

    @Override
    public Integer desertification(String zone, String imageDate) {
        return mapper.desertification(zone,imageDate);
    }

    @Override
    public Integer moisture(String zone, String imageDate) {
        return mapper.moisture(zone,imageDate);
    }

    @Override
    public Integer salinization(String zone, String imageDate) {
        return mapper.salinization(zone,imageDate);
    }

    @Override
    public Integer healthy(String zone, String imageDate,String resolution) {
        return mapper.healthy(zone,imageDate,resolution);
    }

    @Override
    public Integer water(String zone, String imageDate) {
        return mapper.water(zone,imageDate);
    }

    @Override
    public Integer waterArea(String zone, String imageDate) {
        return mapper.waterArea(zone,imageDate);
    }

    @Override
    public Integer roadLength(String zone, String imageDate) {
        return mapper.roadLength(zone,imageDate);
    }

    @Override
    public Integer climateIndex(String zone, String imageDate) {
        return mapper.climateIndex(zone,imageDate);
    }


}
